/**
 * Copyright (c) 2011, Ben Fortuna
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  o Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 *  o Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 *  o Neither the name of Ben Fortuna nor the names of any other contributors
 * may be used to endorse or promote products derived from this software
 * without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package net.fortuna.mstor;

import java.util.ArrayList;
import java.util.List;

import javax.mail.Folder;
import javax.mail.Store;

import junit.framework.TestCase;

/**
 * Abstract base class for MStor unit tests. Provides setup of a mail store.
 * 
 * @author Ben Fortuna
 * 
 * <pre>
 * $Id$
 *
 * Created on 6/05/2006
 * </pre>
 * 
 */
public abstract class AbstractMStorTest extends TestCase {

    protected StoreLifecycle lifecycle;
    
    protected Store store;
    
    protected String username;
    
    protected String password;
    
    protected String[] folderNames;

    public AbstractMStorTest(String method, StoreLifecycle lifecycle,
            String username, String password) {
        
        super(method);
        this.lifecycle = lifecycle;
        this.username = username;
        this.password = password;
    }

    /* (non-Javadoc)
     * @see junit.framework.TestCase#setUp()
     */
    protected void setUp() throws Exception {
        super.setUp();
        lifecycle.startup();
        store = lifecycle.getStore();
        store.connect(username, password);
        
        List<String> folderList = new ArrayList<String>();
        Folder[] folders = store.getDefaultFolder().list();
        if (folders.length == 0) {
            // create dummy folders..
            for (int i = 0; i < 10; i++) {
                Folder f = store.getDefaultFolder().getFolder("folder_" + i);
                f.create(Folder.HOLDS_MESSAGES);
            }
            folders = store.getDefaultFolder().list();
        }
        
        for (int i = 0; i < folders.length; i++) {
            folderList.add(folders[i].getName());
        }
        folderNames = folderList.toArray(new String[folderList.size()]);
    }
    
    /* (non-Javadoc)
     * @see junit.framework.TestCase#tearDown()
     */
    protected void tearDown() throws Exception {
        store.close();
        lifecycle.shutdown();
        super.tearDown();
    }
}
