/**
 * Copyright (c) 2011, Ben Fortuna
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  o Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 *  o Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 *  o Neither the name of Ben Fortuna nor the names of any other contributors
 * may be used to endorse or promote products derived from this software
 * without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package net.fortuna.mstor.data;

import java.io.File;
import java.io.FileFilter;
import java.io.IOException;
import java.nio.ByteBuffer;

import org.apache.commons.io.FileUtils;
import org.apache.commons.io.IOUtils;
import org.apache.commons.io.filefilter.DirectoryFileFilter;
import org.apache.commons.io.filefilter.NotFileFilter;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * @author Ben
 * 
 * <pre>
 * $Id$
 *
 * Created on 03/03/2008
 * </pre>
 * 
 *
 */
public class MessageInputStreamTest extends TestCase {

    private File testFile;
    
    private MessageInputStream in;
    
    /**
     * @param method
     * @param testFile
     */
    public MessageInputStreamTest(String method, File testFile) {
        super(method);
        this.testFile = testFile;
    }
    
    /* (non-Javadoc)
     * @see junit.framework.TestCase#setUp()
     */
    protected void setUp() throws Exception {
        super.setUp();
        byte[] message = FileUtils.readFileToByteArray(testFile);
        in = new MessageInputStream(ByteBuffer.wrap(message));
    }
    
    /**
     * 
     */
    public void testRead() throws IOException {
        String message = IOUtils.toString(in);
        assertNotNull(message);
    }
    
    /**
     * @return
     */
    public static Test suite() {

        TestSuite suite = new TestSuite(MessageInputStream.class.getSimpleName());
        
        File[] testFiles = new File("etc/samples/messages").listFiles(
                (FileFilter) new NotFileFilter(DirectoryFileFilter.INSTANCE));
        
        for (int i = 0; i < testFiles.length; i++) {
            suite.addTest(new MessageInputStreamTest("testRead", testFiles[i]));
        }
        return suite;
    }
    
}
